@@ -15,13 +15,13 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
     $VERSION = eval $VERSION;
 
 ## Load our modules
@@ -102,14 +102,16 @@ This module exports a single method - getSNTPTime and an error
 =item * RFC4330 OUTPUT
 
     -RFC4330: This is an optional way to produce an easy visual
-    output based on RFC4330 documentation.
+    output based on RFC4330 documentation. Expected input is a string,
+    integer or boolean in the form (0 or 1).
 
 
 =item * CLEARSCREEN
 
     -clearScreen: This is an optional choice based on user preference
     if he/she desires to clear the "terminal screen" before printing
-    the captured data.
+    the captured data. Expected input is a string, integer or boolean
+    in the form (0 or 1).
 
 =back
 
@@ -193,6 +195,17 @@ sub getSNTPTime {
 	}
 	return TRUE;
     };
+
+    my $verify_boolean = sub {
+	my $input = shift;
+	return FALSE if (!defined $input);
+	if ( defined $input && $input =~ /^[0-9]+$/ ) {
+	    if ( $input eq "0" or $input eq "1" ) {
+		return FALSE;
+	    }
+	}
+	return TRUE;
+    };
     
     my $dot = ".";
     my $error = undef;
@@ -204,6 +217,8 @@ sub getSNTPTime {
     return ($error = "Not defined key(s)", \%moduleInput) if ($checkHashKeys->(%moduleInput));
     return ($error = "Not defined Hostname", \%moduleInput) if (!$moduleInput{-hostname});
     return ($error = "Not correct port number", \%moduleInput) if ($verify_port->($moduleInput{-port}));
+    return ($error = "Not correct RFC4330 input", \%moduleInput) if ($verify_boolean->($moduleInput{-RFC4330}));
+    return ($error = "Not correct clearScreen input", \%moduleInput) if ($verify_boolean->($moduleInput{-clearScreen}));
 
     my $client_socket;
 
@@ -524,7 +539,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 9.0  2015/07/14 00:18:31 am  Thanos
+Revision 10.0  2015/07/16 01:38:31 am  Thanos
 
 
 =cut
